@@ -1,7 +1,7 @@
 // qjackctlAboutForm.cpp
 //
 /****************************************************************************
-   Copyright (C) 2003-2007, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2009, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -84,6 +84,12 @@ qjackctlAboutForm::qjackctlAboutForm (
     sText += "<br />\n";
     sText += "</font></small>";
 #endif
+#ifndef CONFIG_JACK_PORT_ALIASES
+    sText += "<small><font color=\"red\">";
+    sText += tr("JACK Port aliases support disabled.");
+    sText += "<br />\n";
+    sText += "</font></small>";
+#endif
 #ifndef CONFIG_ALSA_SEQ
 #if !defined(WIN32)
     sText += "<small><font color=\"red\">";
@@ -91,6 +97,14 @@ qjackctlAboutForm::qjackctlAboutForm (
     sText += "<br />\n";
     sText += "</font></small>";
 #endif
+#endif
+#ifndef CONFIG_DBUS
+#if !defined(WIN32)
+    sText += "<small><font color=\"red\">";
+    sText += tr("D-Bus interface support disabled.");
+    sText += "<br />\n";
+    sText += "</font></small>";
+#endif
 #endif
     sText += "<br />\n";
     sText += tr("Website") + ": <a href=\"" QJACKCTL_WEBSITE "\">" QJACKCTL_WEBSITE "</a><br />\n";
