@@ -1,7 +1,7 @@
 // qjackctlPatchbay.cpp
 //
 /****************************************************************************
-   Copyright (C) 2003-2008, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2009, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -545,7 +545,7 @@ bool qjackctlSocketList::removeSocketItem (void)
 			"\"%2\"\n\nAre you sure?")
 			.arg(m_sSocketCaption)
 			.arg(pSocketItem->socketName()),
-			tr("Yes"), tr("No")) == 0) {
+			QMessageBox::Yes | QMessageBox::No) == QMessageBox::Yes) {
 			delete pSocketItem;
 			bResult = true;
 			m_pListView->setDirty(true);
@@ -1292,7 +1292,7 @@ void qjackctlPatchbayView::contextMenu ( const QPoint& pos,
 			tr("Exclusive"), pSocketList, SLOT(exclusiveSocketItem()));
 		pAction->setCheckable(true);
 		pAction->setChecked(bEnabled && pSocketItem->isExclusive());
-		pAction->setEnabled(bEnabled /* && (pSocketItem->connects().count() < 2) */);
+		pAction->setEnabled(bEnabled && (pSocketItem->connects().count() < 2));
 		// Construct the forwarding menu,
 		// overriding the last one, if any...
 		QMenu *pForwardMenu = menu.addMenu(tr("Forward"));
@@ -1619,7 +1619,7 @@ bool qjackctlPatchbay::connectSelected (void)
 	connectSockets(pOSocket, pISocket);
 
 	// Making one list dirty will take care of the rest...
-	(m_pOSocketList->listView())->setDirty(true);
+	m_pPatchbayView->setDirty(true);
 
 	return true;
 }
@@ -1711,7 +1711,7 @@ bool qjackctlPatchbay::disconnectSelected (void)
 	disconnectSockets(pOSocket, pISocket);
 
 	// Making one list dirty will take care of the rest...
-	(m_pOSocketList->listView())->setDirty(true);
+	m_pPatchbayView->setDirty(true);
 
 	return true;
 }
@@ -1738,7 +1738,7 @@ bool qjackctlPatchbay::disconnectAll (void)
 		tr("Warning") + " - " QJACKCTL_SUBTITLE1,
 		tr("This will disconnect all sockets.\n\n"
 		"Are you sure?"),
-		tr("Yes"), tr("No")) > 0) {
+		QMessageBox::Yes | QMessageBox::No) == QMessageBox::No) {
 		return false;
 	}
 
@@ -1751,7 +1751,7 @@ bool qjackctlPatchbay::disconnectAll (void)
 	}
 
 	// Making one list dirty will take care of the rest...
-	(m_pOSocketList->listView())->setDirty(true);
+	m_pPatchbayView->setDirty(true);
 
 	return true;
 }
@@ -1961,6 +1961,9 @@ void qjackctlPatchbay::connectionsSnapshot (void)
 	rack.connectJackSnapshot(jackClient());
 	rack.connectAlsaSnapshot(alsaSeq());
 	loadRack(&rack);
+
+	// Set dirty flag.
+	m_pPatchbayView->setDirty(true);
 }
 
 
