@@ -1,7 +1,7 @@
 // qjackctlPatchbayFile.h
 //
 /****************************************************************************
-   Copyright (C) 2003-2006, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2007, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -24,18 +24,17 @@
 
 #include "qjackctlPatchbayRack.h"
 
-#include <qfile.h>
-#include <qtextstream.h>
-
 
 // Patchbay XML definition.
 class qjackctlPatchbayFile
 {
 public:
 
-    // Simple patchbay I/O methods.
-    static bool load (qjackctlPatchbayRack *pPatchbay, const QString& sFilename);
-    static bool save (qjackctlPatchbayRack *pPatchbay, const QString& sFilename);
+	// Simple patchbay I/O methods.
+	static bool load (qjackctlPatchbayRack *pPatchbay,
+		const QString& sFilename);
+	static bool save (qjackctlPatchbayRack *pPatchbay,
+		const QString& sFilename);
 };
 
 
