@@ -37,6 +37,19 @@ qjackctlSetup::qjackctlSetup (void)
 	bStartJack = false;
 	sDefPresetName = QObject::tr("(default)");
 
+	loadSetup();
+}
+
+// Destructor;
+qjackctlSetup::~qjackctlSetup (void)
+{
+	saveSetup();
+}
+
+
+// Explicit load method.
+void qjackctlSetup::loadSetup (void)
+{
 	m_settings.beginGroup("/Presets");
 	sDefPreset = m_settings.value("/DefPreset", sDefPresetName).toString();
 	QString sPrefix = "/Preset%1";
@@ -50,6 +63,8 @@ qjackctlSetup::qjackctlSetup (void)
 	m_settings.endGroup();
 
 	m_settings.beginGroup("/Options");
+	bSingleton               = m_settings.value("/Singleton", true).toBool();
+//	sServerName              = m_settings.value("/ServerName").toString();
 	bStartJack               = m_settings.value("/StartJack", false).toBool();
 	bStartupScript           = m_settings.value("/StartupScript", true).toBool();
 	sStartupScriptShell      = m_settings.value("/StartupScriptShell", "artsshell -q terminate").toString();
@@ -121,8 +136,8 @@ qjackctlSetup::qjackctlSetup (void)
 }
 
 
-// Destructor;
-qjackctlSetup::~qjackctlSetup (void)
+// Explicit save method.
+void qjackctlSetup::saveSetup (void)
 {
 	// Save all settings and options...
 	m_settings.beginGroup("/Program");
@@ -143,6 +158,8 @@ qjackctlSetup::~qjackctlSetup (void)
 	m_settings.endGroup();
 
 	m_settings.beginGroup("/Options");
+	m_settings.setValue("/Singleton",               bSingleton);
+//	m_settings.setValue("/ServerName",              sServerName);
 	m_settings.setValue("/StartJack",               bStartJack);
 	m_settings.setValue("/StartupScript",           bStartupScript);
 	m_settings.setValue("/StartupScriptShell",      sStartupScriptShell);
@@ -211,6 +228,9 @@ qjackctlSetup::~qjackctlSetup (void)
 	while (!m_settings.value(sPrefix.arg(++i)).toString().isEmpty())
 		m_settings.remove(sPrefix.arg(i));
 	m_settings.endGroup();
+
+	// Commit all changes to disk.
+	m_settings.sync();
 }
 
 
@@ -422,6 +442,8 @@ void qjackctlSetup::print_usage ( const QString& arg0 )
 		QObject::tr("Set default settings preset name") + sEol;
 	out << "  -a, --active-patchbay=[path]" + sEot +
 		QObject::tr("Set active patchbay definition file") + sEol;
+	out << "  -n, --server-name=[label]" + sEot +
+		QObject::tr("Set default JACK audio server name") + sEol;
 	out << "  -h, --help" + sEot +
 		QObject::tr("Show help about command line options") + sEol;
 	out << "  -v, --version" + sEot +
@@ -478,6 +500,15 @@ bool qjackctlSetup::parse_args ( const QStringList& args )
 			if (iEqual < 0)
 				i++;
 		}
+		else if (sArg == "-n" || sArg == "--server-name") {
+			if (sVal.isNull()) {
+				out << QObject::tr("Option -n requires an argument (name).") + sEol;
+				return false;
+			}
+			sServerName = sVal;
+			if (iEqual < 0)
+				i++;
+		}
 		else if (sArg == "-h" || sArg == "--help") {
 			print_usage(args.at(0));
 			return false;
