@@ -87,9 +87,13 @@ public:
 
 	// Constructor.
 	qjackctlSetup();
-	// destructor;
+	// Destructor;
 	~qjackctlSetup();
 
+	// Explicit I/O methods.
+	void loadSetup();
+	void saveSetup();
+
 	// Command line arguments parser.
 	bool parse_args(const QStringList& args);
 	// Command line usage helper.
@@ -110,6 +114,8 @@ public:
 	QStringList presets;
 
 	// Options...
+	bool    bSingleton;
+	QString sServerName;
 	bool    bStartupScript;
 	QString sStartupScriptShell;
 	bool    bPostStartupScript;
