@@ -1,7 +1,7 @@
 // qjackctlSetupForm.cpp
 //
 /****************************************************************************
-   Copyright (C) 2003-2009, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2010, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -388,7 +388,10 @@ qjackctlSetupForm::qjackctlSetupForm (
 	QObject::connect(m_ui.DelayedSetupCheckBox,
 		SIGNAL(stateChanged(int)),
 		SLOT(optionsChanged()));
-	QObject::connect(m_ui.ServerConfigCheckBox,
+	QObject::connect(m_ui.SingletonCheckBox,
+		SIGNAL(stateChanged(int)),
+		SLOT(optionsChanged()));
+	QObject::connect(m_ui.SingletonCheckBox,
 		SIGNAL(stateChanged(int)),
 		SLOT(optionsChanged()));
 	QObject::connect(m_ui.ServerConfigNameComboBox,
@@ -587,6 +590,7 @@ void qjackctlSetupForm::setup ( qjackctlSetup *pSetup )
 	m_ui.SystemTrayCheckBox->setChecked(m_pSetup->bSystemTray);
 	m_ui.StartMinimizedCheckBox->setChecked(m_pSetup->bStartMinimized);
 	m_ui.DelayedSetupCheckBox->setChecked(m_pSetup->bDelayedSetup);
+	m_ui.SingletonCheckBox->setChecked(m_pSetup->bSingleton);
 	m_ui.ServerConfigCheckBox->setChecked(m_pSetup->bServerConfig);
 	setComboBoxCurrentText(m_ui.ServerConfigNameComboBox,
 		m_pSetup->sServerConfigName);
@@ -890,7 +894,7 @@ void qjackctlSetupForm::changeDriverAudio ( const QString& sDriver, int iAudio )
 	bool bPortaudio  = (sDriver == "portaudio");
 	bool bFreebob    = (sDriver == "freebob");
 	bool bFirewire   = (sDriver == "firewire");
-	bool bNet        = (sDriver == "net");
+	bool bNet        = (sDriver == "net" || sDriver == "netone");
 	bool bInEnabled  = false;
 	bool bOutEnabled = false;
 	bool bEnabled;
@@ -967,7 +971,7 @@ void qjackctlSetupForm::changeDriverUpdate ( const QString& sDriver, bool bUpdat
 	bool bCoreaudio = (sDriver == "coreaudio");
 	bool bFreebob   = (sDriver == "freebob");
 	bool bFirewire  = (sDriver == "firewire");
-//	bool bNet       = (sDriver == "net");
+	bool bNet       = (sDriver == "net" || sDriver == "netone");
 
 	m_ui.NoMemLockCheckBox->setEnabled(!bCoreaudio);
 	m_ui.UnlockMemCheckBox->setEnabled(!bCoreaudio
@@ -990,6 +994,12 @@ void qjackctlSetupForm::changeDriverUpdate ( const QString& sDriver, bool bUpdat
 		m_ui.PrioritySpinBox->setEnabled(bPriorityEnabled);
 	}
 
+	m_ui.SampleRateTextLabel->setEnabled(!bNet);
+	m_ui.SampleRateComboBox->setEnabled(!bNet);
+
+	m_ui.FramesTextLabel->setEnabled(!bNet);
+	m_ui.FramesComboBox->setEnabled(!bNet);
+	
 	m_ui.PeriodsTextLabel->setEnabled(bAlsa || bSun || bOss || bFreebob || bFirewire);
 	m_ui.PeriodsSpinBox->setEnabled(bAlsa || bSun || bOss || bFreebob || bFirewire);
 
@@ -1111,6 +1121,10 @@ void qjackctlSetupForm::stabilizeForm (void)
 	m_ui.DelayedSetupCheckBox->setEnabled(
 		!m_ui.StartMinimizedCheckBox->isChecked());
 
+#if !defined(Q_WS_X11)
+	m_ui.SingletonCheckBox->setEnabled(false);
+#endif
+
 	m_ui.TransportButtonsCheckBox->setEnabled(
 		m_ui.LeftButtonsCheckBox->isChecked());
 
@@ -1781,6 +1795,7 @@ void qjackctlSetupForm::accept (void)
 		m_pSetup->bSystemTray              = m_ui.SystemTrayCheckBox->isChecked();
 		m_pSetup->bStartMinimized          = m_ui.StartMinimizedCheckBox->isChecked();
 		m_pSetup->bDelayedSetup            = m_ui.DelayedSetupCheckBox->isChecked();
+		m_pSetup->bSingleton               = m_ui.SingletonCheckBox->isChecked();
 		m_pSetup->bServerConfig            = m_ui.ServerConfigCheckBox->isChecked();
 		m_pSetup->sServerConfigName        = m_ui.ServerConfigNameComboBox->currentText();
 		m_pSetup->bServerConfigTemp        = m_ui.ServerConfigTempCheckBox->isChecked();
@@ -1810,6 +1825,9 @@ void qjackctlSetupForm::accept (void)
 	m_pSetup->saveComboBoxHistory(m_ui.MessagesLogPathComboBox);
 	m_pSetup->saveComboBoxHistory(m_ui.ServerConfigNameComboBox);
 
+	// Save/commit to disk.
+	m_pSetup->saveSetup();
+
 	// Just go with dialog acceptance.
 	QDialog::accept();
 }
