@@ -1,7 +1,7 @@
 // qjackctlSocketForm.cpp
 //
 /****************************************************************************
-   Copyright (C) 2003-2009, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2010, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -322,9 +322,26 @@ bool qjackctlSocketForm::validateForm (void)
 // Validate form fields and accept it valid.
 void qjackctlSocketForm::accept (void)
 {
+	if (m_pSocketList == NULL)
+		return;
+
 	if (!validateForm())
 		return;
 
+	// Check if a socket with the same name already exists...
+	QListIterator<qjackctlSocketItem *> iter(m_pSocketList->sockets());
+	while (iter.hasNext()) {
+		const QString& sSocketName = iter.next()->socketName();
+		if (m_ui.SocketNameLineEdit->text() == sSocketName) {
+			QMessageBox::critical(this,
+				tr("Error") + " - " QJACKCTL_SUBTITLE1,
+				tr("A socket named \"%1\" already exists.")
+				.arg(sSocketName), QMessageBox::Cancel);
+			// Reject.
+			return;
+		}
+	}
+
 	QDialog::accept();
 }
 
