@@ -1,7 +1,7 @@
 // qjackctlStatusForm.cpp
 //
 /****************************************************************************
-   Copyright (C) 2003-2007, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2009, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -58,6 +58,8 @@ qjackctlStatusForm::qjackctlStatusForm (
 	pHeader->setMovable(false);
 	pHeader->setStretchLastSection(true);
 
+	m_apStatus[STATUS_SERVER_NAME] = new QTreeWidgetItem(m_ui.StatsListView,
+		QStringList() << s + tr("Server name") + c << n);
 	m_apStatus[STATUS_SERVER_STATE] = new QTreeWidgetItem(m_ui.StatsListView,
 		QStringList() << s + tr("Server state") + c << n);
 	m_apStatus[STATUS_DSP_LOAD]     = new QTreeWidgetItem(m_ui.StatsListView,
@@ -178,4 +180,25 @@ void qjackctlStatusForm::updateStatusItem ( int iStatusItem,
 }
 
 
+// Keyboard event handler.
+void qjackctlStatusForm::keyPressEvent ( QKeyEvent *pKeyEvent )
+{
+#ifdef CONFIG_DEBUG_0
+	qDebug("qjackctlStatusForm::keyPressEvent(%d)", pKeyEvent->key());
+#endif
+	int iKey = pKeyEvent->key();
+	switch (iKey) {
+	case Qt::Key_Escape:
+		close();
+		break;
+	default:
+		QWidget::keyPressEvent(pKeyEvent);
+		break;
+	}
+
+	// Make sure we've get focus back...
+	QWidget::setFocus();
+}
+
+
 // end of qjackctlStatusForm.cpp
